@@ -9,8 +9,7 @@ from pysts.utils.utils import to_json_serializable
 from datetime import datetime
 
 from pysts.utils.utils import create_logger
-logger = create_logger(__name__)
-logger.info(f'Mongo engine: logging as name: {__name__}')
+logger = create_logger(__name__) #pysts.db.mongodb.engine
 connect=mongoengine.connect
 Document=mongoengine.DynamicDocument
 
@@ -72,25 +71,22 @@ def update_or_create(self,query=None,*args,files=None,unique_keys=None,**kwargs)
         ids = result.inserted_ids
         msg='insert_many'
 
-    elif len(query)>0 and len(updates)>0: #Bulk write update many
+    elif len(query)>0 and len(updates)==1 and '$set' in updates: #Bulk insert many
+        setq=updates['$set']
         ops=[];combined_query={'$or':[]}
         if unique_keys is None:
             unique_keys=[key for key,val in query[0].items() if type(val) not in [list,tuple,np.ndarray]]
         for cur_query in query:
+            ops.append({**cur_query,**setq})
             cur_query_unique_keys={key:val for key,val in cur_query.items() if key in unique_keys}
-            set_updates = {'$set':{key:val for key,val in cur_query.items() if key not in unique_keys}}
-
-            if len(set_updates)>0 and '$set' in updates:
-                set_updates['$set']={**updates['$set'],**set_updates['$set']}
-
-            cur_updates={**{key:val for key,val in updates.items() if key!='$set'},**set_updates}
-            ops.append(UpdateMany(cur_query_unique_keys, cur_updates,upsert=True))
             combined_query['$or'].append(cur_query_unique_keys)
 
-        result=db_collection.bulk_write(ops)
+        deleted=db_collection.delete_many(combined_query)
+        logger.debug(f'update_or_create: Deleted {deleted.deleted_count} documents')
+        result=db_collection.insert_many(ops)
 
-        ids=[x['_id'] for x in db_collection.find(combined_query,projection='_id')]
-        msg='bulk_write (UpdateMany)'
+        ids=result.inserted_ids
+        msg='insert_many (with updates)'
     else:
         raise Exception(f'Nothing to update or create: query={query}; and updates={updates}')
 
